@@ -8,18 +8,20 @@
 #         Jerome Carnis, carnis_jerome@yahoo.fr
 
 import json
-import matplotlib as mpl
-import matplotlib.pyplot as plt
-from numbers import Real
-import numpy as np
 import os
 import pathlib
+import tkinter as tk
+from numbers import Real
+from tkinter import filedialog
+
+import matplotlib as mpl
+import matplotlib.pyplot as plt
+import numpy as np
 from scipy.interpolate import interp1d
 from scipy.ndimage.measurements import center_of_mass
-import tkinter as tk
-from tkinter import filedialog
-import bcdi.postprocessing.facet_recognition as fu
+
 import bcdi.graph.graph_utils as gu
+import bcdi.postprocessing.facet_recognition as fu
 import bcdi.utils.utilities as util
 import bcdi.utils.validation as valid
 
@@ -125,9 +127,7 @@ file_path = filedialog.askopenfilename(
 )
 _, ext = os.path.splitext(file_path)
 if ext in {".png", ".jpg", ".tif"}:
-    obj = util.image_to_ndarray(
-        filename=file_path, convert_grey=True, cmap="gray", debug=False
-    )
+    obj = util.image_to_ndarray(filename=file_path, convert_grey=True)
 else:
     obj, _ = util.load_file(file_path)
 
