@@ -7,16 +7,19 @@
 #       authors:
 #         Jerome Carnis, carnis_jerome@yahoo.fr
 
-import numpy as np
-from matplotlib import pyplot as plt
-from lmfit import minimize, Parameters, report_fit
+import os
 import pathlib
 import tkinter as tk
 from tkinter import filedialog
-import os
+
+import numpy as np
+from lmfit import Parameters, minimize, report_fit
+from matplotlib import pyplot as plt
+
 import bcdi.graph.graph_utils as gu
-import bcdi.utils.utilities as util
 import bcdi.postprocessing.postprocessing_utils as pu
+import bcdi.utils.utilities as util
+from bcdi.graph.colormap import ColormapFactory
 
 helptext = """
 Extract the surface voxel layer of an object recontructed by BCDI phase retrieval and
@@ -69,8 +72,7 @@ pathlib.Path(savedir).mkdir(parents=True, exist_ok=True)
 ###################
 # define colormap #
 ###################
-colormap = gu.Colormap()
-my_cmap = colormap.cmap
+my_cmap = ColormapFactory().cmap
 
 #############
 # load data #
@@ -125,58 +127,55 @@ if debug:
 # save the strain values #
 ##########################
 if save_txt:
-    file_surface = open(
+    with open(
         os.path.join(
             savedir,
             "S" + str(scan) + "_threshold" + str(support_threshold) + "_surface.dat",
         ),
         "w",
-    )
-    file_bulk = open(
+    ) as file_surface, open(
         os.path.join(
             savedir,
             "S" + str(scan) + "_threshold" + str(support_threshold) + "_bulk.dat",
         ),
         "w",
-    )
-    file_total = open(
-        os.path.join(
-            savedir,
-            "S"
-            + str(scan)
-            + "_threshold"
-            + str(support_threshold)
-            + "_bulk+surface.dat",
-        ),
-        "w",
-    )
-    # write surface points position / strain to file
-    surface_indices = np.nonzero(surface)
-    nb_surface = len(surface_indices[0])
-    ind_z = surface_indices[0]
-    ind_y = surface_indices[1]
-    ind_x = surface_indices[2]
-    for point in range(nb_surface):
-        file_surface.write(
-            "{0: <10}".format(
-                str("{:.7f}".format(strain[ind_z[point], ind_y[point], ind_x[point]]))
-            )
-            + "\n"
-        )
+    ) as file_bulk:
 
-    # write bulk points position / strain to file
-    bulk_indices = np.nonzero(bulk)
-    nb_bulk = len(bulk_indices[0])
-    ind_z = bulk_indices[0]
-    ind_y = bulk_indices[1]
-    ind_x = bulk_indices[2]
-    for point in range(nb_bulk):
-        file_bulk.write(
-            "{0: <10}".format(
-                str("{:.7f}".format(strain[ind_z[point], ind_y[point], ind_x[point]]))
+        # write surface points position / strain to file
+        surface_indices = np.nonzero(surface)
+        nb_surface = len(surface_indices[0])
+        ind_z = surface_indices[0]
+        ind_y = surface_indices[1]
+        ind_x = surface_indices[2]
+        for point in range(nb_surface):
+            file_surface.write(
+                "{0: <10}".format(
+                    str(
+                        "{:.7f}".format(
+                            strain[ind_z[point], ind_y[point], ind_x[point]]
+                        )
+                    )
+                )
+                + "\n"
+            )
+
+        # write bulk points position / strain to file
+        bulk_indices = np.nonzero(bulk)
+        nb_bulk = len(bulk_indices[0])
+        ind_z = bulk_indices[0]
+        ind_y = bulk_indices[1]
+        ind_x = bulk_indices[2]
+        for point in range(nb_bulk):
+            file_bulk.write(
+                "{0: <10}".format(
+                    str(
+                        "{:.7f}".format(
+                            strain[ind_z[point], ind_y[point], ind_x[point]]
+                        )
+                    )
+                )
+                + "\n"
             )
-            + "\n"
-        )
     file_surface.close()
     file_bulk.close()
 
@@ -186,17 +185,28 @@ if save_txt:
     ind_z = total_indices[0]
     ind_y = total_indices[1]
     ind_x = total_indices[2]
-    for point in range(nb_total):
-        file_total.write(
-            "{0: <10}".format(
-                str("{:.7f}".format(strain[ind_z[point], ind_y[point], ind_x[point]]))
+    with open(
+        os.path.join(
+            savedir,
+            "S"
+            + str(scan)
+            + "_threshold"
+            + str(support_threshold)
+            + "_bulk+surface.dat",
+        ),
+        "w",
+    ) as file_total:
+        for point in range(nb_total):
+            file_total.write(
+                "{0: <10}".format(
+                    str(
+                        "{:.7f}".format(
+                            strain[ind_z[point], ind_y[point], ind_x[point]]
+                        )
+                    )
+                )
+                + "\n"
             )
-            + "\n"
-        )
-
-    file_surface.close()
-    file_bulk.close()
-    file_total.close()
 
 ####################################
 # fit the bulk strain distribution #
@@ -218,15 +228,15 @@ x_axis = bin_edges[:-1] + (bin_edges[1] - bin_edges[0]) / 2
 
 fit_params = Parameters()
 if fit_pdf == "skewed_gaussian":
-    fit_params.add("amp_1", value=0.0005, min=0.000001, max=10000)
-    fit_params.add("loc_1", value=0, min=-0.1, max=0.1)
-    fit_params.add("sig_1", value=0.0005, min=0.0000001, max=0.1)
-    fit_params.add("alpha_1", value=0, min=-10, max=10)
+    fit_params.add("amp_0", value=0.0005, min=0.000001, max=10000)
+    fit_params.add("loc_0", value=0, min=-0.1, max=0.1)
+    fit_params.add("sig_0", value=0.0005, min=0.0000001, max=0.1)
+    fit_params.add("alpha_0", value=0, min=-10, max=10)
 else:  # 'pseudovoigt'
-    fit_params.add("amp_1", value=0.0005, min=0.000001, max=10000)
-    fit_params.add("cen_1", value=0, min=-0.1, max=0.1)
-    fit_params.add("sig_1", value=0.0005, min=0.0000001, max=0.1)
-    fit_params.add("ratio_1", value=0.5, min=0, max=1)
+    fit_params.add("amp_0", value=0.0005, min=0.000001, max=10000)
+    fit_params.add("cen_0", value=0, min=-0.1, max=0.1)
+    fit_params.add("sig_0", value=0.0005, min=0.0000001, max=0.1)
+    fit_params.add("ratio_0", value=0.5, min=0, max=1)
 
 # run the global fit to all the data sets
 result = minimize(util.objective_lmfit, fit_params, args=(x_axis, hist, fit_pdf))
@@ -320,7 +330,7 @@ if fit_pdf == "skewed_gaussian":
         0.13,
         0.66,
         "SK std={:.2e}\n   +/-{:.2e}".format(
-            result.params["sig_1"].value, result.params["sig_1"].stderr
+            result.params["sig_0"].value, result.params["sig_0"].stderr
         ),
     )
 else:
@@ -328,21 +338,21 @@ else:
         0.15,
         0.70,
         "PDF center={:.2e}\n   +/-{:.2e}".format(
-            result.params["cen_1"].value, result.params["cen_1"].stderr
+            result.params["cen_0"].value, result.params["cen_0"].stderr
         ),
     )
     fig.text(
         0.15,
         0.60,
         "PDF std={:.2e}\n   +/-{:.2e}".format(
-            result.params["sig_1"].value, result.params["sig_1"].stderr
+            result.params["sig_0"].value, result.params["sig_0"].stderr
         ),
     )
     fig.text(
         0.15,
         0.50,
         "PDF ratio={:.2e}\n   +/-{:.2e}".format(
-            result.params["ratio_1"].value, result.params["ratio_1"].stderr
+            result.params["ratio_0"].value, result.params["ratio_0"].stderr
         ),
     )
 plt.pause(0.1)
@@ -374,15 +384,15 @@ x_axis = bin_edges[:-1] + (bin_edges[1] - bin_edges[0]) / 2
 
 fit_params = Parameters()
 if fit_pdf == "skewed_gaussian":
-    fit_params.add("amp_1", value=0.001, min=0.00000001, max=100000)
-    fit_params.add("loc_1", value=0, min=-0.1, max=0.1)
-    fit_params.add("sig_1", value=0.0005, min=0.0000001, max=0.1)
-    fit_params.add("alpha_1", value=0, min=-10, max=10)
+    fit_params.add("amp_0", value=0.001, min=0.00000001, max=100000)
+    fit_params.add("loc_0", value=0, min=-0.1, max=0.1)
+    fit_params.add("sig_0", value=0.0005, min=0.0000001, max=0.1)
+    fit_params.add("alpha_0", value=0, min=-10, max=10)
 else:  # 'pseudovoigt'
-    fit_params.add("amp_1", value=0.001, min=0.00000001, max=100000)
-    fit_params.add("cen_1", value=0, min=-0.1, max=0.1)
-    fit_params.add("sig_1", value=0.0005, min=0.0000001, max=0.1)
-    fit_params.add("ratio_1", value=0.5, min=0, max=1)
+    fit_params.add("amp_0", value=0.001, min=0.00000001, max=100000)
+    fit_params.add("cen_0", value=0, min=-0.1, max=0.1)
+    fit_params.add("sig_0", value=0.0005, min=0.0000001, max=0.1)
+    fit_params.add("ratio_0", value=0.5, min=0, max=1)
 
 # run the global fit to all the data sets
 result = minimize(util.objective_lmfit, fit_params, args=(x_axis, hist, fit_pdf))
@@ -472,7 +482,7 @@ if fit_pdf == "skewed_gaussian":
         0.13,
         0.66,
         "SK std={:.2e}\n   +/-{:.2e}".format(
-            result.params["sig_1"].value, result.params["sig_1"].stderr
+            result.params["sig_0"].value, result.params["sig_0"].stderr
         ),
     )
 else:
@@ -480,21 +490,21 @@ else:
         0.15,
         0.70,
         "PDF center={:.2e}\n   +/-{:.2e}".format(
-            result.params["cen_1"].value, result.params["cen_1"].stderr
+            result.params["cen_0"].value, result.params["cen_0"].stderr
         ),
     )
     fig.text(
         0.15,
         0.60,
         "PDF std={:.2e}\n   +/-{:.2e}".format(
-            result.params["sig_1"].value, result.params["sig_1"].stderr
+            result.params["sig_0"].value, result.params["sig_0"].stderr
         ),
     )
     fig.text(
         0.15,
         0.50,
         "PDF ratio={:.2e}\n   +/-{:.2e}".format(
-            result.params["ratio_1"].value, result.params["ratio_1"].stderr
+            result.params["ratio_0"].value, result.params["ratio_0"].stderr
         ),
     )
 plt.pause(0.1)
