@@ -1,24 +1,27 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 
+import gc
+import sys
+import tkinter as tk
+from tkinter import filedialog
+
+import matplotlib.pyplot as plt
+
 # BCDI: tools for pre(post)-processing Bragg coherent X-ray diffraction imaging data
 #   (c) 07/2017-06/2019 : CNRS UMR 7344 IM2NP
 #   (c) 07/2019-present : DESY PHOTON SCIENCE
 #       authors:
 #         Jerome Carnis, carnis_jerome@yahoo.fr
 import numpy as np
-import matplotlib.pyplot as plt
-import tkinter as tk
-from tkinter import filedialog
 from scipy.interpolate import RegularGridInterpolator
-import gc
-import sys
-import bcdi.postprocessing.postprocessing_utils as pu
-import bcdi.graph.graph_utils as gu
+
 import bcdi.algorithms.algorithms_utils as algu
+import bcdi.graph.graph_utils as gu
+import bcdi.postprocessing.postprocessing_utils as pu
 import bcdi.utils.utilities as util
 from bcdi.experiment.setup import Setup
-
+from bcdi.graph.colormap import ColormapFactory
 
 helptext = """
 Create a support from a reconstruction, using the indicated threshold. The support
@@ -257,8 +260,7 @@ def press_key(event):
 ###################
 # define colormap #
 ###################
-colormap = gu.Colormap()
-my_cmap = colormap.cmap
+my_cmap = ColormapFactory().cmap
 plt.rcParams["keymap.fullscreen"] = [""]
 
 #################
@@ -488,10 +490,8 @@ print(
 print(
     "Original voxel sizes in detector coordinates based on "
     "experimental parameters (ver, hor): "
-    "{:.2f} nm, {:.2f} nm".format(
-        12.398 * 1e-7 / energy * distance / (unbinned_shape[1] * pixel_y) * 1e9,
-        12.398 * 1e-7 / energy * distance / (unbinned_shape[2] * pixel_x) * 1e9,
-    )
+    f"{12.398 * 1e-7 / energy * distance / (unbinned_shape[1] * pixel_y) * 1e9:.2f} nm, "
+    f"{12.398 * 1e-7 / energy * distance / (unbinned_shape[2] * pixel_x) * 1e9:.2f} nm"
 )
 
 rebinned_shape = [
@@ -622,7 +622,7 @@ if not all(
 
     else:  # data in detector frame
         setup = Setup(
-            beamline=beamline,
+            beamline_name=beamline,
             energy=energy,
             outofplane_angle=outofplane_angle,
             inplane_angle=inplane_angle,
@@ -643,15 +643,11 @@ if not all(
 
     print(
         "Original voxel sizes zyx (nm):",
-        str("{:.2f}".format(voxelsize_z)),
-        str("{:.2f}".format(voxelsize_y)),
-        str("{:.2f}".format(voxelsize_x)),
+        f"{voxelsize_z:.2f}, {voxelsize_y:.2f}, {voxelsize_x:.2f}",
     )
     print(
         "Output voxel sizes zyx (nm):",
-        str("{:.2f}".format(newvoxelsize_z)),
-        str("{:.2f}".format(newvoxelsize_y)),
-        str("{:.2f}".format(newvoxelsize_x)),
+        f"{newvoxelsize_z:.2f}, {newvoxelsize_y:.2f}, {newvoxelsize_x:.2f}",
     )
 
     # Interpolate the support
