@@ -7,16 +7,19 @@
 #       authors:
 #         Jerome Carnis, carnis_jerome@yahoo.fr
 
+import tkinter as tk
+from tkinter import filedialog
+
+import matplotlib.ticker as ticker
 import numpy as np
 from matplotlib import pyplot as plt
 from scipy.ndimage.measurements import center_of_mass
-import tkinter as tk
-from tkinter import filedialog
-import matplotlib.ticker as ticker
-import bcdi.postprocessing.postprocessing_utils as pu
-from bcdi.utils import image_registration as reg
+
 import bcdi.graph.graph_utils as gu
+import bcdi.postprocessing.postprocessing_utils as pu
 import bcdi.utils.utilities as util
+from bcdi.graph.colormap import ColormapFactory
+from bcdi.utils import image_registration as reg
 
 helptext = """
 Load several reconstructed complex objects and calculate the coefficient variation
@@ -92,8 +95,7 @@ if grey_background:
     bad_color = "0.7"
 else:
     bad_color = "1.0"  # white background
-colormap = gu.Colormap(bad_color=bad_color)
-my_cmap = colormap.cmap
+my_cmap = ColormapFactory(bad_color=bad_color).cmap
 
 #############
 # load data #
