@@ -7,13 +7,16 @@
 #       authors:
 #         Jerome Carnis, carnis_jerome@yahoo.fr
 
-import numpy as np
-import matplotlib.pyplot as plt
 import tkinter as tk
 from tkinter import filedialog
+
+import matplotlib.pyplot as plt
+import numpy as np
+
 import bcdi.graph.graph_utils as gu
 import bcdi.utils.utilities as util
 import bcdi.xcca.xcca_utils as xcca
+from bcdi.graph.colormap import ColormapFactory
 
 helptext = """
 Plot a 1D angular average of a 3D reciprocal space map, based on the position of the
@@ -59,8 +62,7 @@ subtract_median = False  # if True, will subtract the median to the mean at each
 ###################
 # define colormap #
 ###################
-colormap = gu.Colormap()
-my_cmap = colormap.cmap
+my_cmap = ColormapFactory().cmap
 
 ##############################
 # load reciprocal space data #
