@@ -7,15 +7,15 @@
 #       authors:
 #         Jerome Carnis, carnis_jerome@yahoo.fr
 
-from lmfit import minimize, Parameters, report_fit
-import matplotlib.pyplot as plt
-import numpy as np
-
-from scipy.interpolate import interp1d
-
+import sys
 import tkinter as tk
 from tkinter import filedialog
-import sys
+
+import matplotlib.pyplot as plt
+import numpy as np
+from lmfit import Parameters, minimize, report_fit
+from scipy.interpolate import interp1d
+
 import bcdi.utils.utilities as util
 
 helptext = """
@@ -39,7 +39,7 @@ fit_range = [
     [0.70, 0.90],
 ]  # list of ranges for simultaneous fit [[start1, stop1],[start2, stop2],...]
 constraint_expr = [
-    "sqrt(8)/sqrt(3) * cen_1"
+    "sqrt(8)/sqrt(3) * cen_0"
 ]  # list of string constraints for the fit, leave [] otherwise
 # if provided, len(constraint_expr) should be equal to len(fit_range)-1
 # sqrt(8)/sqrt(3), ratio of 220 to 111 in FCC materials
@@ -140,22 +140,22 @@ for idx in range(nb_ranges):
     if lineshape == "gaussian":
         cen = (fit_range[idx, 0] + fit_range[idx, 1]) / 2
         sig = abs(fit_range[idx, 0] - fit_range[idx, 1]) / 16
-        fit_params.add("amp_%i" % (idx + 1), value=10, min=0.0, max=1000)
-        fit_params.add("cen_%i" % (idx + 1), value=cen, min=cen - 0.5, max=cen + 0.5)
-        fit_params.add("sig_%i" % (idx + 1), value=sig, min=sig / 32, max=sig * 4)
+        fit_params.add("amp_%i" % idx, value=10, min=0.0, max=1000)
+        fit_params.add("cen_%i" % idx, value=cen, min=cen - 0.5, max=cen + 0.5)
+        fit_params.add("sig_%i" % idx, value=sig, min=sig / 32, max=sig * 4)
     elif lineshape == "lorentzian":
         cen = (fit_range[idx, 0] + fit_range[idx, 1]) / 2
         sig = abs(fit_range[idx, 0] - fit_range[idx, 1]) / 16
-        fit_params.add("amp_%i" % (idx + 1), value=10, min=0.0, max=1000)
-        fit_params.add("cen_%i" % (idx + 1), value=cen, min=cen - 0.5, max=cen + 0.5)
-        fit_params.add("sig_%i" % (idx + 1), value=sig, min=sig / 32, max=sig * 4)
+        fit_params.add("amp_%i" % idx, value=10, min=0.0, max=1000)
+        fit_params.add("cen_%i" % idx, value=cen, min=cen - 0.5, max=cen + 0.5)
+        fit_params.add("sig_%i" % idx, value=sig, min=sig / 32, max=sig * 4)
     elif lineshape == "pseudovoigt":
         cen = (fit_range[idx, 0] + fit_range[idx, 1]) / 2
         sig = abs(fit_range[idx, 0] - fit_range[idx, 1]) / 8  # FWHM of the Pseudo Voigt
-        fit_params.add("amp_%i" % (idx + 1), value=10, min=0.0, max=1000)
-        fit_params.add("cen_%i" % (idx + 1), value=cen, min=cen - 0.5, max=cen + 0.5)
-        fit_params.add("sig_%i" % (idx + 1), value=sig, min=sig / 32, max=sig * 4)
-        fit_params.add("ratio_%i" % (idx + 1), value=0.5, min=0, max=1)
+        fit_params.add("amp_%i" % idx, value=10, min=0.0, max=1000)
+        fit_params.add("cen_%i" % idx, value=cen, min=cen - 0.5, max=cen + 0.5)
+        fit_params.add("sig_%i" % idx, value=sig, min=sig / 32, max=sig * 4)
+        fit_params.add("ratio_%i" % idx, value=0.5, min=0, max=1)
 
 # constrain values
 if len(constraint_expr) != 0:
@@ -168,7 +168,7 @@ if len(constraint_expr) != 0:
         )
         sys.exit()
     for idx in range(1, nb_ranges):
-        fit_params[constraint_var[idx - 1] + "_%i" % (idx + 1)].expr = constraint_expr[
+        fit_params[constraint_var[idx - 1] + "_%i" % idx].expr = constraint_expr[
             idx - 1
         ]
 
@@ -203,6 +203,19 @@ try:
     fig.text(
         0.15,
         0.95,
+        "cen_0 = "
+        + str("{:.5f}".format(result.params["cen_0"].value))
+        + "+/-"
+        + str("{:.5f}".format(result.params["cen_0"].stderr))
+        + "   sig_0 = "
+        + str("{:.5f}".format(result.params["sig_0"].value))
+        + "+/-"
+        + str("{:.5f}".format(result.params["sig_0"].stderr)),
+        size=12,
+    )
+    fig.text(
+        0.15,
+        0.90,
         "cen_1 = "
         + str("{:.5f}".format(result.params["cen_1"].value))
         + "+/-"
@@ -213,19 +226,6 @@ try:
         + str("{:.5f}".format(result.params["sig_1"].stderr)),
         size=12,
     )
-    fig.text(
-        0.15,
-        0.90,
-        "cen_2 = "
-        + str("{:.5f}".format(result.params["cen_2"].value))
-        + "+/-"
-        + str("{:.5f}".format(result.params["cen_2"].stderr))
-        + "   sig_2 = "
-        + str("{:.5f}".format(result.params["sig_2"].value))
-        + "+/-"
-        + str("{:.5f}".format(result.params["sig_2"].stderr)),
-        size=12,
-    )
 except TypeError:  # one output is None
     fig.text(0.15, 0.90, "at least one output is None", size=12)
 fig.text(0.15, 0.80, lineshape + " fit", size=12)
